* ------------------------------------------------------------------------------
* Australian data: bias and disagreement
* ------------------------------------------------------------------------------

cls
capture restore
set more off

* Directory to save output
cd "${mystart}/Dropbox/Inflation Expectations/Melbourne Institute/Output"

* Load macro data
import excel using "${mystart}/Dropbox/Inflation Expectations/Macroeconomic data/Australia/Input.xlsx", sheet("Monthly") cellrange(A10:H397) firstrow clear
gen year = year(date)
gen month = month(date)
replace date = ym(year,month)
format date %tm
keep if year>=1993
order date year month, first
save cpi.dta, replace

* Load inflation expectations data
import excel using "${mystart}/Dropbox/Inflation Expectations/Melbourne Institute/Output/Graphs.xlsx", sheet("Mean") cellrange(A1:I283) firstrow clear
gen year = year(date)
gen month = month(date)
replace date = ym(year,month)
format date %tm
keep if year>=1994
order date year month, first
save exp.dta, replace

* Load inflation expectations data, by high and low inflation uncertainty
import excel using "${mystart}/Dropbox/Inflation Expectations/Melbourne Institute/Output/Graphs.xlsx", sheet("Uncertainty") cellrange(A1:M283) firstrow clear
gen year = year(date)
gen month = month(date)
replace date = ym(year,month)
format date %tm
keep if year>=1994
order date year month, first

* Merge datasets
merge 1:1 date using exp.dta
drop _merge
merge 1:1 date using cpi.dta
drop _merge
erase exp.dta
erase cpi.dta

* Declare time series
sort date
tsset date

* Choose CPI series
drop CPI
rename CPIexInt CPI

* Rename inflation expectations series
rename ExpIndOtherDK ExpOther

* ------------------------------------------------------------------------------
* Construct variables
* ------------------------------------------------------------------------------

* Indicator for ALP government
gen ALPgovt = 0
replace ALPgovt = 1 if date<=tm(1996m2) | (date>=tm(2007m12) & date<=tm(2013m8))

* Indicator for GST period (announcement to introduction)
gen GST = 0
replace GST = date if date>=tm(1998m8) & date<=tm(2000m7)

* Inflation rates (annualised)
gen CPI_q = 400*log(CPI/L3.CPI)
gen CPI_ye = 100*log(CPI/L12.CPI)
gen coreCPI_q = 400*log(coreCPI/L3.coreCPI)
gen coreCPI_ye = 100*log(coreCPI/L12.coreCPI)

* Relative inflation expectations
gen rExp_ALP_Other = ExpALP - ExpOther
gen rExp_LibNat_Other = ExpLibNat - ExpOther
gen rExp_ALP_LibNat = ExpALP - ExpLibNat
gen rExpLow_ALP_LibNat = ExpLow_ALP - ExpLow_LibNat
gen rExpHigh_ALP_LibNat = ExpHigh_ALP - ExpHigh_LibNat

* Change in oil price
gen dWTI_AUD = 100*log(WTI_AUD/L.WTI_AUD)
gen d3WTI_AUD = 100*log(WTI_AUD/L3.WTI_AUD)
gen d12WTI_AUD = 100*log(WTI_AUD/L12.WTI_AUD)

* Change in automotive fuel prices
gen autofuel_q = 400*log(autofuel/L3.autofuel)

* Change in unemployment rate
gen d3unempRate = unempRate - L3.unempRate
gen d12unempRate = unempRate - L12.unempRate

* Absolute values 
gen dCPI_q_abs = abs(CPI_q - L.CPI_q)
gen dExpOther_abs = abs(ExpOther -  L.ExpOther)

* Estimation sample
gen sample = 1 if date>=tm(1994m10) & date<=tm(2017m3)

* ------------------------------------------------------------------------------
* Regressions: bias, all consumers
* ------------------------------------------------------------------------------

* Inflation expectations: Others, by party
newey ExpOther ALPgovt if sample==1, lag(18)
outreg2 using Bias.xls, replace ctitle(OLS, ExpOther) keep(ALPgovt) nocons dec(3) 

* Inflation expectations: ALP, by party
newey ExpALP ALPgovt if sample==1, lag(18)
outreg2 using Bias.xls, append ctitle(OLS, ExpALP) keep(ALPgovt) nocons dec(3) 

* Inflation expectations: Lib/Nat, by party
newey ExpLibNat ALPgovt if sample==1, lag(18)
outreg2 using Bias.xls, append ctitle(OLS, ExpLibNat) keep(ALPgovt) nocons dec(3) 

* ALP, relative to Others
newey rExp_ALP_Other ALPgovt if sample==1, lag(18)
outreg2 using Bias.xls, append ctitle(OLS, ALP-Other) keep(ALPgovt) nocons dec(3) 

* Lib/Nat, relative to Others
newey rExp_LibNat_Other ALPgovt if sample==1, lag(18)
outreg2 using Bias.xls, append ctitle(OLS, LibNat-Other) keep(ALPgovt) nocons dec(3) 

* ------------------------------------------------------------------------------
* Response to data
* ------------------------------------------------------------------------------

* ALP voter expectations
newey ExpALP ALPgovt CPI_q relativeCPI d3unempRate ExpOther if sample==1, lag(18)
outreg2 using Disagreement.xls, replace ctitle(OLS, ALP) dec(3) addtext()

* Lib/Nat voter expectations
newey ExpLibNat ALPgovt CPI_q relativeCPI d3unempRate ExpOther if sample==1, lag(18)
outreg2 using Disagreement.xls, append ctitle(OLS, Lib/Nat) dec(3) addtext()

* Disagreement (ALP minus Lib/Nat)
newey rExp_ALP_LibNat ALPgovt CPI_q relativeCPI d3unempRate ExpOther if sample==1, lag(18)
outreg2 using Disagreement.xls, append ctitle(OLS, ALP-Lib/Nat) dec(3) addtext()

* Disagreement (ALP minus Lib/Nat)
newey rExp_ALP_LibNat ALPgovt CPI_q relativeCPI d3unempRate ExpOther dCPI_q_abs unempRate if sample==1, lag(18)
outreg2 using Disagreement.xls, append ctitle(OLS, ALP-Lib/Nat) dec(3) addtext()

* ------------------------------------------------------------------------------
* Uncertainty
* ------------------------------------------------------------------------------

* Low uncertainty types
newey rExpLow_ALP_LibNat ALPgovt if sample==1, lag(18)

* High uncertainty types
newey rExpHigh_ALP_LibNat ALPgovt if sample==1, lag(18)
